@@ -1,5 +1,8 @@
 from profile_python.profile import Profile
 
-if __name__ == "__main__":
+def main():
     profile = Profile()
     profile.run_app()
+
+if __name__ == "__main__":
+    main()
